import requests
import json


class Api:
    def __init__(self, key, base_url='http://www.baidu.com'):
        self.key = key
        self.base_url = base_url

    def get_url(self, url):
        return "%s/%s" % (self.base_url, url)

    def upload_machine_and_get_task(self, data={}):
        return requests.post(self.get_url('project/machine/%s' % (data.get('mac'))), data=json.dumps(data),
                             headers={'Content-Type': 'application/json'}).json()

    def get_config_by_key(self):
        key = self.key
        return {
            "from": {"account_name": "eubtestdownload",
                     "account_key": "OKCVxAo5INdYAa5JmiVA2m1dk6dYStG4JI2lDku8rFqMKTj4qKUq0CrcsFfzDIoGoGEGUsRbQxDxG94IQYNnBw==",
                     "endpoint_suffix": "core.chinacloudapi.cn"},
            "to": {"account_name": "eubtestdownload",
                   "account_key": "OKCVxAo5INdYAa5JmiVA2m1dk6dYStG4JI2lDku8rFqMKTj4qKUq0CrcsFfzDIoGoGEGUsRbQxDxG94IQYNnBw==",
                   "endpoint_suffix": "core.chinacloudapi.cn"}
        }



from apscheduler.schedulers.background import BlockingScheduler
import docker
import status
import utils
from uuid import getnode as get_mac
import api


class Watch:
    def __init__(self, time):
        self.time = time
        self.key = None
        self.api = api.Api(None, "http://eubchain.local")

    def upload_machine_information(self):
        client = docker.from_env()
        current_status = status.Status.IDLE.value
        if len(client.containers()) > 0:
            current_status = status.Status.RUNNING.value
        data = utils.get_device_info()
        data['status_info'] = {
            'key': self.key,
            'status': current_status
        }
        data['mac'] = get_mac()
        response = self.api.upload_machine_and_get_task(data)
        print(data, response)

    def watch(self):
        scheduler = BlockingScheduler()
        scheduler.add_job(self.upload_machine_information, 'interval', seconds=self.time)
        scheduler.start()
